@@ -17,8 +17,6 @@ from typing import (
     Set,
 )
 
-from typing_extensions import final
-
 from syrupy.constants import (
     SNAPSHOT_DIRNAME,
     SYMBOL_CARRIAGE,
@@ -44,7 +42,7 @@ from syrupy.terminal import (
 from syrupy.utils import walk_snapshot_dir
 
 if TYPE_CHECKING:
-    from syrupy.location import TestLocation
+    from syrupy.location import PyTestLocation
     from syrupy.types import (
         PropertyFilter,
         PropertyMatcher,
@@ -72,7 +70,7 @@ class SnapshotSerializer(ABC):
 class SnapshotFossilizer(ABC):
     @property
     @abstractmethod
-    def test_location(self) -> "TestLocation":
+    def test_location(self) -> "PyTestLocation":
         raise NotImplementedError
 
     def get_snapshot_name(self, *, index: int = 0) -> str:
@@ -83,7 +81,8 @@ class SnapshotFossilizer(ABC):
     def get_location(self, *, index: int) -> str:
         """Returns full location where snapshot data is stored."""
         basename = self._get_file_basename(index=index)
-        return str(Path(self._dirname).joinpath(f"{basename}.{self._file_extension}"))
+        fileext = f".{self._file_extension}" if self._file_extension else ""
+        return str(Path(self._dirname).joinpath(f"{basename}{fileext}"))
 
     def is_snapshot_location(self, *, location: str) -> bool:
         """Checks if supplied location is valid for this snapshot extension"""
@@ -106,14 +105,14 @@ class SnapshotFossilizer(ABC):
 
         return discovered
 
-    @final
     def read_snapshot(self, *, index: int) -> "SerializedData":
         """
         Utility method for reading the contents of a snapshot assertion.
         Will call `_pre_read`, then perform `read` and finally `post_read`,
         returning the contents parsed from the `read` method.
 
-        Override `_read_snapshot_data_from_location` in subclass to change behaviour
+        This method is _final_, do not override. You can override
+        `_read_snapshot_data_from_location` in a subclass to change behaviour.
         """
         try:
             self._pre_read(index=index)
@@ -128,13 +127,13 @@ class SnapshotFossilizer(ABC):
         finally:
             self._post_read(index=index)
 
-    @final
     def write_snapshot(self, *, data: "SerializedData", index: int) -> None:
         """
         Utility method for writing the contents of a snapshot assertion.
         Will call `_pre_write`, then perform `write` and finally `_post_write`.
 
-        Override `_write_snapshot_fossil` in subclass to change behaviour
+        This method is _final_, do not override. You can override
+        `_write_snapshot_fossil` in a subclass to change behaviour.
         """
         self._pre_write(data=data, index=index)
         snapshot_location = self.get_location(index=index)
@@ -373,9 +372,9 @@ class SnapshotReporter(ABC):
 
 
 class AbstractSyrupyExtension(SnapshotSerializer, SnapshotFossilizer, SnapshotReporter):
-    def __init__(self, test_location: "TestLocation"):
+    def __init__(self, test_location: "PyTestLocation"):
         self._test_location = test_location
 
     @property
-    def test_location(self) -> "TestLocation":
+    def test_location(self) -> "PyTestLocation":
         return self._test_location
