@@ -53,7 +53,7 @@ def requirements(ctx, upgrade=False):
         f"{' '.join(args)} - -qo- | sed '/^-e / d' > dev_requirements.txt",
     )
 
-    with open("min_requirements.txt", "w", encoding="utf-8") as f:
+    with open("min_requirements.constraints", "w", encoding="utf-8") as f:
         min_requirements = _parse_min_versions(install_requires)
         f.write("\n".join(min_requirements))
         f.write("\n")
@@ -93,7 +93,6 @@ def install(ctx):
 @task(
     help={
         "coverage": "Build and report on test coverage",
-        "dev": "Use syrupy development version",
         "test-pattern": "Pattern used to select test files to run",
         "update-snapshots": "Create, update or delete snapshot files",
         "verbose": "Verbose output e.g. non captured logs etc.",
@@ -102,7 +101,6 @@ def install(ctx):
 def test(
     ctx,
     coverage=False,
-    dev=False,
     test_pattern=None,
     update_snapshots=False,
     verbose=False,
@@ -110,7 +108,6 @@ def test(
     """
     Run entire test suite
     """
-    env = {"PYTHONPATH": "./src"} if dev else {}
     flags = {
         "-s -vv": verbose,
         f"-k {test_pattern}": test_pattern,
@@ -118,9 +115,9 @@ def test(
     }
     coverage_module = "coverage run -m " if coverage else ""
     test_flags = " ".join(flag for flag, enabled in flags.items() if enabled)
-    ctx_run(ctx, f"python -m {coverage_module}pytest {test_flags} .", env=env)
+    ctx_run(ctx, f"python -m {coverage_module}pytest {test_flags} .")
     if coverage:
-        if not os.environ.get("CI"):
+        if not os.environ.get("CI") or not os.environ.get("CODECOV_TOKEN"):
             ctx_run(ctx, "coverage report")
         else:
             ctx_run(ctx, "codecov")
@@ -171,7 +168,8 @@ def release(ctx, dry_run=True):
         should_publish_to_pypi = False
 
     # publish to test to verify builds
-    publish(ctx, dry_run=True)
+    if dry_run:
+        publish(ctx, dry_run=True)
 
     # publish to pypi if test succeeds
     if should_publish_to_pypi:
